%bcond_with bootstrap

# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Summary:        A library for instantiating Java objects
Name:           objenesis
Version:        3.4
Release:        %mkrel 1
Group:          Development/Java
License:        Apache-2.0
URL:            https://objenesis.org/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://github.com/easymock/%{name}/archive/%{version}.tar.gz

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
%endif
# xmvn-builddep misses this:
%if %{without bootstrap}
BuildRequires:  mvn(org.apache:apache-jar-resource-bundle)
%endif

%description
Objenesis is a small Java library that serves one purpose: to instantiate 
a new object of a particular class.
Java supports dynamic instantiation of classes using Class.newInstance(); 
however, this only works if the class has an appropriate constructor. There 
are many times when a class cannot be instantiated this way, such as when 
the class contains constructors that require arguments, that have side effects,
and/or that throw exceptions. As a result, it is common to see restrictions 
in libraries stating that classes must require a default constructor. 
Objenesis aims to overcome these restrictions by bypassing the constructor 
on object instantiation. Needing to instantiate an object without calling 
the constructor is a fairly specialized task, however there are certain cases 
when this is useful:
* Serialization, Remoting and Persistence - Objects need to be instantiated 
  and restored to a specific state, without invoking code.
* Proxies, AOP Libraries and Mock Objects - Classes can be sub-classed without 
  needing to worry about the super() constructor.
* Container Frameworks - Objects can be dynamically instantiated in 
  non-standard ways.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

%pom_remove_dep :junit-bom

# Enable generation of pom.properties (rhbz#1017850)
%pom_xpath_remove pom:addMavenDescriptor

%pom_remove_plugin :maven-timestamp-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin -r :maven-shade-plugin
%pom_remove_plugin -r org.sonatype.plugins:nexus-staging-maven-plugin
%pom_xpath_remove "pom:dependency[pom:scope='test']" tck

%pom_xpath_remove pom:build/pom:extensions

%pom_disable_module module-test

# Missing dependencies
rm tck/src/test/java/org/objenesis/tck/OsgiTest.java

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc LICENSE.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt


%changelog
* Thu Jun 20 2024 daviddavid <daviddavid> 3.4-1.mga10
+ Revision: 2075607
- Update to version 3.4
- Remove dependency on junit-bom

* Mon May 27 2024 daviddavid <daviddavid> 3.3-2.mga10
+ Revision: 2067928
- rebuild for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 3.3-1.mga10
+ Revision: 1986723
- Update to upstream version 3.3

* Mon Jul 25 2022 neoclust <neoclust> 3.1-11.mga9
+ Revision: 1871096
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 3.1-10.mga9
+ Revision: 1870824
- Add a bootstrap mode
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Sep 04 2020 daviddavid <daviddavid> 3.1-1.mga8
+ Revision: 1621575
- bumped  to 3.1
- disabled javadoc generation. It requires maven pomming beyond my skills
- Rebuilt for JDK-11
- Fix build with Java 11

* Wed Feb 12 2020 umeabot <umeabot> 2.6-3.mga8
+ Revision: 1503333
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 2.6-2.mga7
+ Revision: 1281318
- Mageia 7 Mass Rebuild

* Sun Oct 01 2017 daviddavid <daviddavid> 2.6-1.mga7
+ Revision: 1162342
- Update to upstream version 2.6
- Add missing BR on apache-resource-bundles

* Thu May 18 2017 neoclust <neoclust> 2.1-5.mga6
+ Revision: 1102875
- Fix build with current maven-jar-plugin
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 2.1-3.mga6
+ Revision: 977748
- First rebuild of the java stack
- sync package objenesis with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Dec 28 2014 dmorgan <dmorgan> 1.2-16.mga5
+ Revision: 806907
- Rebuild against fixed stack

* Wed Oct 15 2014 umeabot <umeabot> 1.2-8.mga5
+ Revision: 742254
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat Jun 14 2014 dmorgan <dmorgan> 1.2-6.mga5
+ Revision: 636205
- Build with xmvn

* Fri Oct 18 2013 umeabot <umeabot> 1.2-5.mga4
+ Revision: 508415
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.2-4.mga3
+ Revision: 361112
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jul 09 2012 dmorgan <dmorgan> 1.2-3.mga3
+ Revision: 269034
- Update to current Java packaging guidelines
- Remove maven-eclipse-plugin BR
- Added patch2 - JRockitInstantntiatorCharacters.patch to fix unmappable characters
- Added build requires  apache-resource-bundles and  maven-remote-resources-plugin
- Improve project description
- Build with mvn-rpmbuild
- Fix License
- Comment on skipped tests
- Build with maven 3

* Mon Sep 05 2011 dmorgan <dmorgan> 1.2-2.mga2
+ Revision: 138739
- Remove P1
- Adapt to mageia guidelines
+ gil <gil>
- edit spec file  used new %%add_maven_depmap macro

* Tue Jul 19 2011 dmorgan <dmorgan> 1.2-1.mga2
+ Revision: 126818
- Clean spec file
+ gil <gil>
- renoved patch1 for mockito
- add patch1 for mockito
- imported package objenesis


* Thu Jun 30 2011 gil <gil> 1.2-0.%%mkrel
- initial rpm